library(dplyr)
library(tibble)
library(readr)


# Create agglomeration parameters table -----------------------------------

parameters <- tibble(sector = c("Manufacturing",
                                "Construction",
                                "Wholesale_Retail",
                                "Transport",
                                "Inf_Comm_Tech",
                                "Fin_Bus_Services"),
                     gva_per_worker = c(109370.00, 56708.00, 0, 51901.00, 0, 93841.00),
                     decay_parameter = c(1.25, 1, 1, 1.25, 1.5, 1.5),
                     elasticity = c(0.015, 0.065, 0, 0.092, 0, 0.058))


# Create GVA factors table ------------------------------------------------

discount_rate <- c(0.04, 0.035, 0.03, 0.025, 0.02, 0.015)

gva_factors <- tibble(year = 2016:2200) %>%
    mutate(appraisal_year = case_when(
        year < format(Sys.Date(), "%Y") ~ 0,
        year >= format(Sys.Date(), "%Y") ~ (row_number() - (as.numeric(format(Sys.Date(), "%Y")) - 2016 + 1))
        )) %>%
    mutate(discount = case_when(
        appraisal_year %in% 0:30 ~ 1/((1 + discount_rate[1]) ^ (year - 2016)),
        appraisal_year %in% 31:60 ~ 1/(((1 + discount_rate[1]) ^ (year - 2016 - (appraisal_year - 30)))*((1 + discount_rate[2]) ^ (appraisal_year - 30))),
        appraisal_year %in% 61:100 ~ 1/(((1 + discount_rate[1]) ^ (year - 2016 - (appraisal_year - 30)))*((1 + discount_rate[2]) ^ (30))*((1 + discount_rate[3]) ^ (appraisal_year - 60))),
        appraisal_year %in% 101:175 ~ 1/(((1 + discount_rate[1]) ^ (year - 2016 - (appraisal_year - 30)))*((1 + discount_rate[2]) ^ (30))*((1 + discount_rate[3]) ^ (40))*((1 + discount_rate[4]) ^ (appraisal_year - 100))),
        appraisal_year %in% 176:275 ~ 1/(((1 + discount_rate[1]) ^ (year - 2016 - (appraisal_year - 30)))*((1 + discount_rate[2]) ^ (30))*((1 + discount_rate[3]) ^ (40))*((1 + discount_rate[4]) ^ (75))*((1 + discount_rate[5]) ^ (appraisal_year - 175))),
        appraisal_year > 275 ~ 1/(((1 + discount_rate[1]) ^ (year - 2016 - (appraisal_year - 30)))*((1 + discount_rate[2]) ^ (30))*((1 + discount_rate[3]) ^ (40))*((1 + discount_rate[4]) ^ (75))*((1 + discount_rate[5]) ^ (100))*((1 + discount_rate[5]) ^ (appraisal_year - 275))),
    ),
    gva_growth = case_when(
        year %in% c(2016:2019) ~ 1.049,
        # year == 2016 ~ 1,
        year %in% c(2020:2024) ~ 1.022,
        TRUE ~ 1.023),
    gva_compound = cumprod(gva_growth))


# Load internal data for testing -----------------------------------------------

path_gc_dm_2024 <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/2024Impedance_DM.txt"
path_gc_ds_2024 <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/2024Impedance_DS.txt"
path_gc_dm_2039 <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/2039Impedance_DM.txt"
path_gc_ds_2039 <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/2039Impedance_DS.txt"
path_gc_dm_2054 <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/2054Impedance_DM.txt"
path_gc_ds_2054 <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/2054Impedance_DS.txt"

path_jobs <- "/home/dan/R/projects/agglomeration/aecom-python/foynes-limerick/Jobs.txt"
path_ntpm_jobs <- "/home/dan/R/projects/agglomeration/data/ntpm-jobs.txt"

read_gc <- function(path) {
    read_table2(path,
                col_names = c("o_zone",
                              "d_zone",
                              "uc",
                              "tp1",
                              "tp2",
                              "tp3")) %>%
        select(o_zone, d_zone, tp1) %>%
        rename(gen_cost = tp1)
}

dm_2024 <- read_gc(path_gc_dm_2024)
ds_2024 <- read_gc(path_gc_ds_2024)
dm_2039 <- read_gc(path_gc_dm_2039)
ds_2039 <- read_gc(path_gc_ds_2039)
dm_2054 <- read_gc(path_gc_dm_2054)
ds_2054 <- read_gc(path_gc_ds_2054)

sample_jobs <- read_jobs(path_jobs)
ntpm_jobs <- read_jobs(path_ntpm_jobs)

# Add tests to data/ folder -----------------------------------------------

usethis::use_data(parameters, overwrite = TRUE)
usethis::use_data(gva_factors, overwrite = TRUE)

usethis::use_data(dm_2024,
                  ds_2024,
                  dm_2039,
                  ds_2039,
                  dm_2054,
                  ds_2054,
                  sample_jobs,
                  ntpm_jobs,
                  internal = FALSE,
                  overwrite = TRUE)
